==> core-4.17.0.tgz: package/src/commands/MakeProviderCommand.js <==
/**
 * @athenna/core
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Path } from '@athenna/common';
import { sep, resolve, isAbsolute } from 'node:path';
import { BaseCommand, Argument } from '@athenna/artisan';
export class MakeProviderCommand extends BaseCommand {
    static signature() {
        return 'make:provider';
    }
    static description() {
        return 'Make a new provider file.';
    }
    async handle() {
        this.logger.simple('({bold,green} [ MAKING PROVIDER ])\n');
        const file = await this.generator
            .path(this.getFilePath())
            .template('provider')
            .setNameProperties(true)
            .make();
        this.logger.success(`Provider ({yellow} "${file.name}") successfully created.`);
        const importPath = this.getImportPath(file.name);
        await this.rc.pushTo('providers', importPath).save();
        this.logger.success(`Athenna RC updated: ({dim,yellow} [ providers += "${importPath}" ])`);
    }
    /**
     * Get the file path where it will be generated.
     */
    getFilePath() {
        return this.getDestinationPath().concat(`${sep}${this.name}.${Path.ext()}`);
    }
    /**
     * Get the destination path for the file that will be generated.
     */
    getDestinationPath() {
        let destination = Config.get('rc.commands.make:provider.destination', Path.providers());
        if (!isAbsolute(destination)) {
            destination = resolve(Path.pwd(), destination);
        }
        return destination;
    }
    /**
     * Get the import path that should be registered in RC file.
     */
    getImportPath(fileName) {
        const destination = this.getDestinationPath();
        return `${destination
            .replace(Path.pwd(), '')
            .replace(/\\/g, '/')
            .replace('/', '#')}/${fileName}`;
    }
}
__decorate([
    Argument({
        description: 'The provider name.'
    }),
    __metadata("design:type", String)
], MakeProviderCommand.prototype, "name", void 0);

==> core-4.26.0.tgz: package/src/commands/MakeProviderCommand.js <==
/**
 * @athenna/core
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Path } from '@athenna/common';
import { BaseCommand, Argument } from '@athenna/artisan';
export class MakeProviderCommand extends BaseCommand {
    static signature() {
        return 'make:provider';
    }
    static description() {
        return 'Make a new provider file.';
    }
    async handle() {
        this.logger.simple('({bold,green} [ MAKING PROVIDER ])\n');
        const destination = Config.get('rc.commands.make:provider.destination', Path.providers());
        const file = await this.generator
            .fileName(this.name)
            .destination(destination)
            .template('provider')
            .setNameProperties(true)
            .make();
        this.logger.success(`Provider ({yellow} "${file.name}") successfully created.`);
        const importPath = this.generator.getImportPath();
        await this.rc.pushTo('providers', importPath).save();
        this.logger.success(`Athenna RC updated: ({dim,yellow} [ providers += "${importPath}" ])`);
    }
}
__decorate([
    Argument({
        description: 'The provider name.'
    }),
    __metadata("design:type", String)
], MakeProviderCommand.prototype, "name", void 0);
